==> gnotepad+_1.0.2.orig.tar.gz: gnotepad+-1.0.2/src/clipboard.c <==
/* vi:set ts=8 sts=0 sw=8:
 * $Id: clipboard.c,v 1.4 1998/10/05 15:36:26 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#include <gtk/gtk.h>
#include "doc.h"
#include "msgbar.h"
#include "clipboard.h"


/*** global function definitions ***/
/*
 * PUBLIC: copy_cb
 *
 * copies text from the text widget into clipboard
 */
void
copy_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = (doc_t *)(w->curdoc);
#ifdef GTK_HAVE_FEATURES_1_1_0
	gtk_editable_copy_clipboard(GTK_EDITABLE(d->txt));
#else
	gtk_editable_copy_clipboard(GTK_EDITABLE(d->txt), GDK_CURRENT_TIME);
#endif
	msgbar_printf(w, "Text copied to clipboard...");
} /* copy_cb */


/*
 * PUBLIC: cub_cb
 *
 * removes text from the text widget and places into clipboard
 */
void
cut_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = (doc_t *)(w->curdoc);
#ifdef GTK_HAVE_FEATURES_1_1_0
	gtk_editable_cut_clipboard(GTK_EDITABLE(d->txt));
#else
	gtk_editable_cut_clipboard(GTK_EDITABLE(d->txt), GDK_CURRENT_TIME);
#endif
	msgbar_printf(w, "Text cut to clipboard...");
} /* cut_cb */


/*
 * PUBLIC: paste_cb
 *
 * pastes clipboard contents into text widget
 */
void
paste_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = (doc_t *)(w->curdoc);
#ifdef GTK_HAVE_FEATURES_1_1_0
	gtk_editable_paste_clipboard(GTK_EDITABLE(d->txt));
#else
	gtk_editable_paste_clipboard(GTK_EDITABLE(d->txt), GDK_CURRENT_TIME);
#endif
	msgbar_printf(w, "Text pasted from clipboard...");
} /* paste_cb */


/*
 * PUBLIC: selall_cb
 *
 * selects the entire contents of the text widget
 */
void
selall_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = (doc_t *)(w->curdoc);
	gtk_editable_select_region(GTK_EDITABLE(d->txt), 0,
		gtk_text_get_length(GTK_TEXT(d->txt)));
	msgbar_printf(w, "All text selected...");
} /* selall_cb */


/* the end */

==> gnotepad+-1.0.8.tar.gz: gnotepad+-1.0.8/src/clipboard.c <==
/* vi:set ts=8 sts=0 sw=8:
 * $Id: clipboard.c,v 1.6 1999/01/18 19:41:45 kahn Exp kahn $
 *
 * Copyright (C) 1998 Andy C. Kahn <kahn@zk3.dec.com>
 *
 *     This program is free software; you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation; either version 2 of the License, or
 *     (at your option) any later version.
 *
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 *
 *     You should have received a copy of the GNU General Public License
 *     along with this program; if not, write to the Free Software
 *     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <gtk/gtk.h>
#include "doc.h"
#include "msgbar.h"
#include "clipboard.h"


/*** global function definitions ***/
/*
 * PUBLIC: copy_cb
 *
 * copies text from the text widget into clipboard
 */
void
copy_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = doc_current(w);
	g_assert(d != NULL);
#ifdef GTK_HAVE_FEATURES_1_1_0
	gtk_editable_copy_clipboard(GTK_EDITABLE(d->data));
#else
	gtk_editable_copy_clipboard(GTK_EDITABLE(d->data), GDK_CURRENT_TIME);
#endif
	msgbar_printf(w, "Text copied to clipboard...");
} /* copy_cb */


/*
 * PUBLIC: cub_cb
 *
 * removes text from the text widget and places into clipboard
 */
void
cut_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = doc_current(w);
	g_assert(d != NULL);
#ifdef GTK_HAVE_FEATURES_1_1_0
	gtk_editable_cut_clipboard(GTK_EDITABLE(d->data));
#else
	gtk_editable_cut_clipboard(GTK_EDITABLE(d->data), GDK_CURRENT_TIME);
#endif
	msgbar_printf(w, "Text cut to clipboard...");
} /* cut_cb */


/*
 * PUBLIC: paste_cb
 *
 * pastes clipboard contents into text widget
 */
void
paste_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = doc_current(w);
	g_assert(d != NULL);
#ifdef GTK_HAVE_FEATURES_1_1_0
	gtk_editable_paste_clipboard(GTK_EDITABLE(d->data));
#else
	gtk_editable_paste_clipboard(GTK_EDITABLE(d->data), GDK_CURRENT_TIME);
#endif
	msgbar_printf(w, "Text pasted from clipboard...");
} /* paste_cb */


/*
 * PUBLIC: selall_cb
 *
 * selects the entire contents of the text widget
 */
void
selall_cb(GtkWidget *widget, gpointer cbdata)
{
	win_t *w = (win_t *)cbdata;
	doc_t *d;

	g_assert(w != NULL);
	d = doc_current(w);
	g_assert(d != NULL);
	gtk_editable_select_region(GTK_EDITABLE(d->data), 0,
		gtk_text_get_length(GTK_TEXT(d->data)));
	msgbar_printf(w, "All text selected...");
} /* selall_cb */


/* the end */
